@@ -1,6 +1,10 @@
 import numpy as np
 import matplotlib.pyplot as plt
 import seaborn as sns
+import rdkit
+from rdkit import Chem
+from rdkit.Chem import AllChem
+from rdkit.Chem import Draw
 
 def plot_single_dist(x):
     sns.distplot(x)
@@ -11,6 +15,11 @@ def plot_overlap_dist(x, y):
     sns.distplot(y)
     plt.show()
 
+def visualize_mol(path, smile):
+    mol = Chem.MolFromSmiles(smile)
+    AllChem.Compute2DCoords(mol)
+    Draw.MolToFile(mol,path)
+
 
 # tester
 #batch = 1000
